from auri.command_line import cli

if __name__ == "__main__":
    cli(prog_name="auri")